<?php
namespace App\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

use App\Exception;
use App\Exception\ApiException as ApiE;

use App\Templates;

class WebService {
    
    private $connection;
    private $integrationService;
    private $util;

    
    public function __construct (\Doctrine\DBAL\Connection $connection,
                                 \App\Service\IntegrationService $integrationService,
                                 \App\Util\Util $util) {
        
        $this->connection         = $connection;
        $this->integrationService = $integrationService;
        $this->util               = $util;
    }
    
    public function welcome(Request $request, Response $response) {
        try {
            $connection = $this->connection->connect();
        } catch(\Exception $e) {
            $connection = false;
        }
        
        $versionInfo = $this->getVersionInfo();
        
        return $response->withJson([
            'version'     => $versionInfo['version'],
            'revision'    => $versionInfo['revision'],
            'date'        => $versionInfo['date'],
            'connection'  => $connection
        ]);
    }

    public function runWebService(Request $request, Response $response) {
        try {
            $req = $request->getParsedBody();
            
            if ($req["auth"] != "81743A8E8D41AF82A4807097CDF4BEC2DDDB9E6334BECCFED4D46FC783A8CA2E") 
                throw new \Exception("Auth inválido.", 666);
                
            $P_INITIAL_DATE = !empty($req["P_INITIAL_DATE"]) ? $req["P_INITIAL_DATE"] : null;
            $P_FINAL_DATE   = !empty($req["P_FINAL_DATE"])   ? $req["P_FINAL_DATE"]   : null;
            
            $configsFile  = file_get_contents(__DIR__ . "/../../configs/configs.json");
            $config       = json_decode($configsFile, true);
            
            $clientFolder = $this->connection->getParams();
            $clientFolder = (isset($clientFolder['dbname'])) ? $clientFolder['dbname'] : "undefined";
            
            $this->basePath          = $config['logPath'] . "/$clientFolder";
            $this->ordersPath        = $this->basePath . "/orders";
            $this->processedPath     = $this->basePath . "/processed";
            $this->errPath           = $this->basePath . "/error";
            $this->networkErrPath    = $this->basePath . "/networkError";
            $this->serverName        = $config['server'];
            
            $this->util->writeLog('execution', null, date('H:i:s')." - Execução da rotina iniciada.\n");
            
            if(empty($P_INITIAL_DATE) && empty($P_FINAL_DATE)) {
                $today = new \DateTimeImmutable();
                $endDate = $today->add(new \DateInterval('P1D'));
                $startDate = $endDate->sub(new \DateInterval('P2D'));
                $P_INITIAL_DATE = $startDate->format('Y-m-d');
                $P_FINAL_DATE = $endDate->format('Y-m-d');
            } else {
                $P_INITIAL_DATE = new \DateTime($P_INITIAL_DATE);
                $P_FINAL_DATE   = new \DateTime($P_FINAL_DATE);

                $P_INITIAL_DATE = date_format($P_INITIAL_DATE,'Y-m-d H:i:s');
                $P_FINAL_DATE   = date_format($P_FINAL_DATE,'Y-m-d H:i:s');
            }
            
            $this->mailList = $this->util->getMailList();
            
            $branchesZigpay = $this->getBranchesZigpay();
            $branchesZigpay = json_decode($branchesZigpay, true);
            
            foreach ($branchesZigpay as $branchZigpay) {

                $branchParams = $this->integrationService->getBranchParams($branchZigpay["id"]);
                
                if(empty($branchParams)) 
                    continue;
                
                $standartParams        = $this->integrationService->getStandartParameters($branchParams['CDFILIAL']);
                $vendor                = $standartParams["CDVENDEDOR"];       
                $operador              = $this->integrationService->getStandartCashier($branchParams['CDFILIAL'], $vendor);
                
                $turcaixa              = $this->integrationService->getOpeningPos($branchParams["CDFILIAL"], $operador["CDCAIXA"]);
                
                if(empty($turcaixa) || empty($turcaixa["DTABERTUR"])) {
                    $opening = [
                        "CDFILIAL"   => $branchParams["CDFILIAL"],
                        "CDCAIXA"    => $operador["CDCAIXA"],
                        "CDOPERADOR" => $operador["CDOPERADOR"]
                    ];

                    try {
                        $this->integrationService->insertTurCaixa($opening);
                    } catch(\Exception $e) {
                        throw new \Exception($e->getMessage());
                    }

                    $turcaixa = $this->integrationService->getOpeningPos($branchParams["CDFILIAL"], $operador["CDCAIXA"]);
                    
                    if(empty($turcaixa["DTABERTUR"]) || !isset($turcaixa["DTABERTUR"])) 
                        throw new \Exception("Não foi possível inserir abertura de caixa para os parâmetros:".$branchParams["CDFILIAL"].", ".$operador["CDCAIXA"]." .");
                        
                } else if(!empty($turcaixa)){
                    $dateOpening = \DateTime::createFromFormat('d/m/Y H:i:s', $turcaixa["DTABERTUR"]);
                    $today = new \DateTime();
                    
                    if($dateOpening->format('d-m-Y') !== $today->format('d-m-Y')) {

                        $salesRevenueZigpay  = $this->getSalesRevenuePerBranch($P_INITIAL_DATE, $P_FINAL_DATE, $branchZigpay["id"]);
                        $salesRevenueZigpay  = json_decode($salesRevenueZigpay, true);
                        
                        $strNotRegistred = "";
                        $paymentsNotRegistred = array();
                        $this->connection->beginTransaction();
                         
                        try {
                            $caixaRevenue = $branchParams["CDFILIAL"]."-".$operador["CDCAIXA"];

                            foreach($salesRevenueZigpay as $recebimento) {

                                $integrationPayment = $this->integrationService->getIntegrationPayment($recebimento['paymentId'], true);

                                if($recebimento['value'] > 0 && !empty($integrationPayment)) {

                                    $idtipomovive = 'G';
                                    $contador     = 'MOVCAIXA'.$branchParams['CDFILIAL'].$operador['CDCAIXA'].$this->util->dateTimeToString($dateOpening);
                                    $nrsequmovi   = $this->util->newCode($contador, 10);

                                    $sangria = [
                                        'CDFILIAL'      => $branchParams["CDFILIAL"],
                                        'CDCAIXA'       => $operador["CDCAIXA"],
                                        'DTABERCAIX'    => $dateOpening,
                                        'NRSEQUMOVI'    => $nrsequmovi,
                                        'IDTIPOMOVIVE'  => $idtipomovive,
                                        'VRMOVIVEND'    => str_replace(".", ",", floatval($recebimento['value'] / 100)),
                                        'CDTIPORECE'    => $integrationPayment["CDTIPORECE"],
                                        'DTHRINCMOV'    => new \DateTime(),
                                        'DTMOVIMCAIXA'  => $dateOpening
                                    ];

                                    $this->integrationService->insertSangria($sangria);
                                    
                                    $receRevenue = $integrationPayment["CDTIPORECE"]."-".str_replace(".", ",", floatval($recebimento['value'] / 100));

                                    $this->util->writeLog('revenue', null, date('H:i:s')." - Inserido a sangria $receRevenue para o caixa $caixaRevenue .\n");

                                } else if (empty($integrationPayment)) {
                                    $paymentsNotRegistred[] = $recebimento;
                                    $strNotRegistred .= $recebimento["paymentName"]." (paymentId: ".$recebimento["paymentId"]."), ";
                                }
                            }
                            
                            $idatuturcaixa = $turcaixa["IDATUTURCAIXA"] == "S" ? "A" : "I";
                            $this->integrationService->closePos($branchParams["CDFILIAL"], $operador["CDCAIXA"], $today, $operador["CDOPERADOR"], $idatuturcaixa);

                            $this->util->writeLog('revenue', null, date('H:i:s')." - Realizado o fechamento do caixa $caixaRevenue .\n");
                            
                            $opening = [
                                "CDFILIAL"   => $branchParams["CDFILIAL"],
                                "CDCAIXA"    => $operador["CDCAIXA"],
                                "CDOPERADOR" => $operador["CDOPERADOR"]
                            ];

                            $this->integrationService->insertTurCaixa($opening);
                            
                            $turcaixa = $this->integrationService->getOpeningPos($branchParams["CDFILIAL"], $operador["CDCAIXA"]);
                            
                            if(empty($turcaixa["DTABERTUR"]) || !isset($turcaixa["DTABERTUR"])) 
                                throw new \Exception("Não foi possível inserir abertura de caixa para os parâmetros:".$branchParams["CDFILIAL"].", ".$operador["CDCAIXA"]." .");
                            
                            $this->util->writeLog('revenue', null, date('H:i:s')." - Realizada a abertura do caixa $caixaRevenue .\n");
                            
                            $this->connection->commit();
                        } catch(\Exception $e) {
                            $this->connection->rollback();
                            throw new \Exception("Erro ao realizar controle de fechamento do caixa: ".$e->getMessage());
                        }
                        
                        if(!empty($paymentsNotRegistred)) {
                            $strNotRegistred = "Os seguintes tipos de recebimento externos do faturamento não foram encontrados na base: ".$strNotRegistred;
                            
                            $this->util->writeLog('revenue_error', $paymentsNotRegistred[0]["eventId"].".txt", $strNotRegistred);
                            
                            $messageBody = file_get_contents(__DIR__ . "/../../templates/defaultTelegramMessage.html");

                            $dataXml['xml'] = "";
                            $this->util->sendTelegramMessage($messageBody, [
                                ":INTEGRACAO"    => 'Teknisa x ZigPay',
                                ":NUMERO_PEDIDO" => $paymentsNotRegistred[0]["eventId"],
                                ":NOME_CLIENTE"  => $config["client"],
                                ":NOME_SERVIDOR" => $config["server"],
                                ":ERRO_MSG"      => $strNotRegistred,
                                ":JSON_PEDIDO"   => json_encode($paymentsNotRegistred, JSON_UNESCAPED_UNICODE),
                                ":GERADO_EM"     => date("d/m/Y H:i:s")
                            ]);
                        }
                    }
                }
                
                $dataXmlsZigpay = [];

                $currentPage = 0;
                while(true) {
                    $currentXml = $this->getXmlsPerBranch($currentPage, $P_INITIAL_DATE, $P_FINAL_DATE, $branchZigpay["id"]);
                    $currentXml = json_decode($currentXml, true);
                    
                    if(empty($currentXml)) {
                        break;
                    }

                    $dataXmlsZigpay = array_merge($dataXmlsZigpay, $currentXml);
                    $currentPage++;
                }
                
                if(!empty($dataXmlsZigpay)) {
                    
                    $configsFile  = file_get_contents(__DIR__ . "/../../configs/configs.json");
                    $config       = json_decode($configsFile, true);
            
                    $clientFolder = $this->connection->getParams();
            
                    $clientFolder = (isset($clientFolder['dbname'])) ? $clientFolder['dbname'] : "undefined";
            
                    $basePath     = $config['logPath'] . "/$clientFolder";
                    
                    $salesDataTest = $this->integrationService->getSalesByIds($branchParams["CDFILIAL"], array_column($dataXmlsZigpay, 'eventId'));
                    $salesData = $this->integrationService->getSalesByIds($branchParams["CDFILIAL"], array_column($dataXmlsZigpay, 'id'));
                    
                    foreach ($dataXmlsZigpay as $dataXml) {
                        
                        $this->connection->beginTransaction();

                        try {
                            $sale  = [];
                            $items = [];
                            
                            $xml = $this->XML2Array($dataXml['xml']);
                            
                            $processedPath = $basePath."/processed";
                            $id = $dataXml['id'];
                            $eventId = $dataXml['eventId'];

                            $idProcessed = glob("$processedPath/{,*/,*/*/,*/*/*/}*$id*.json", GLOB_BRACE);
                            
                            $index = array_search($dataXml["id"], array_column($salesData, 'DSOBSFINVEN'));
                            
                            if($index !== false) 
                                $saleData = $salesData[$index];
                            else 
                                $saleData = null;

                            if(!empty($saleData) || !empty($idProcessed)) {
                                $name = $saleData["CDFILIAL"]."-".$saleData["CDCAIXA"]."-".$saleData["NRSEQVENDA"]."-".$dataXml["id"];
                                $this->util->writeLog('execution', null, date('H:i:s')." - Venda já importada $name.\n");
                                $this->connection->commit();
                                continue;
                            }
                            
                            $this->util->writeLog('order', $dataXml["id"].".json", $xml);
                            
                            $sale["CDFILIAL"]      = $branchParams["CDFILIAL"];
                            $sale["CDLOJA"]        = $operador["CDLOJA"];
                            $sale["CDCAIXA"]       = $operador["CDCAIXA"];
                            $nrseqvenda            = $this->util->newCode('PEDIDOVENDA'.$sale['CDFILIAL'].$sale['CDCAIXA'], 10);
                            $sale['NRSEQVENDA']    = str_pad($nrseqvenda, 10, "0", STR_PAD_LEFT);
                            
                            $dtSale                = new \DateTime($dataXml['eventDate']);
                            $sale['DTVENDA']       = $dtSale;
                            $dtEntrSale            = new \DateTime(substr($dataXml['eventDate'], 0, 10)." 00:00:00.000");
                            $sale['DTENTRVENDA']   = $dtEntrSale;
                            $sale["DTEMISSAONFCE"] = \DateTime::createFromFormat('Y-m-d\TH:i:sP', $xml["NFe"]["infNFe"]["ide"]["dhEmi"]);
                            $sale["VRDESCVENDA"]   = str_replace(".", ",", $xml["NFe"]["infNFe"]["total"]["ICMSTot"]["vDesc"]);
                            $sale["VRTOTVENDA"]    = str_replace(".", ",", $xml["NFe"]["infNFe"]["total"]["ICMSTot"]["vNF"]);
                            $sale["IDSITUVENDA"]   = $dataXml["isCanceled"] == false ? 'O' : 'C';
                            $sale['CDOPERADOR']    = $operador["CDOPERADOR"];
                            $sale["CDCLIENTE"]     = $standartParams["CDCLIENTE"];
                            $sale["CDEMPRESA"]     = $branchParams["CDEMPRESA"];
                            
                            $sale['CDFILIALTUR']   = $sale["CDFILIAL"];
                            $sale['CDCAIXATUR']    = $sale["CDCAIXA"];
                            
                            $sale['DTABERTUR']     = \DateTime::createFromFormat('d/m/Y H:i:s', $turcaixa["DTABERTUR"]);
                            $sale["IDORIGEMVENDA"] = "DLV_INT";
                            $sale["VRTXSEVENDA"]   = 0;
                            $sale["CDCONSUMIDOR"]  = null;
                            $sale["IDVENDEXPORT"]  = null;
                            $sale["NRINSCRCONS"]   = (!empty($xml["NFe"]["infNFe"]["dest"]["CPF"])) ? $xml["NFe"]["infNFe"]["dest"]["CPF"] : null;
                            $sale['NRSERIEIMPVND'] = null;
                            $sale['DSOBSFINVEN'] = $dataXml["id"];
                            
                            $sale['NRACESSONFCE'] = (!empty($xml["protNFe"]["infProt"]["chNFe"])) ? $xml["protNFe"]["infProt"]["chNFe"] : null;
                            
                            $this->integrationService->insertSale($sale);
                            
                            $saleXml = [];
                            $saleXml['CDFILIAL']    = $sale["CDFILIAL"];
                            $saleXml['CDCAIXA']     = $sale["CDCAIXA"];
                            $saleXml['NRSEQVENDA']  = $sale["NRSEQVENDA"];
                            
                            if($sale['IDSITUVENDA'] == 'O') {
                                $saleXml['DSARQXMLNFCE'] = $dataXml["xml"];
                                $saleXml['DSARQXMLCANCNFCE'] = null;
                            } else {
                                $saleXml['DSARQXMLNFCE'] = null;
                                $saleXml['DSARQXMLCANCNFCE'] = $dataXml["xml"];
                            }
                            
                            $this->integrationService->insertSaleXml($saleXml);

                            $products = [];
                            
                            // Confere se det é apenas um produto ou um array com vários produtos
                            if(!empty($xml["NFe"]["infNFe"]["det"]['prod'])) {
                                $products[0] = $xml["NFe"]["infNFe"]["det"];
                            } else {
                                $products = $xml["NFe"]["infNFe"]["det"];
                            }
                            
                            foreach($products as $product) {
                                $item = array();
                                $productDetails = $this->integrationService->getProduct($product['prod']);
                                $item['CDFILIAL']     = $sale["CDFILIAL"];
                                $item['CDCAIXA']      = $sale["CDCAIXA"];
                                $item['CDLOJA']       = $sale["CDLOJA"];
                                $item['NRSEQVENDA']   = $sale["NRSEQVENDA"];
                                $item['NRSEQUITVEND'] = str_pad($product['@attributes']['nItem'], 3, "0", STR_PAD_LEFT);
                                $item['QTPRODVEND']   = intval($product['prod']['qCom']);
                                $item['VRUNITVEND']   = str_replace(".", ",", $product['prod']['vUnCom']);
                                $item['VRDESITVEND']  = 0;
                                $item['VRACRITVEND']  = 0;
                                $item['VRUNITVENDCL'] = 0;
                                $item['CDPRODUTO']    = $productDetails["CDPRODUTO"];
                                $item['NMPRODUTO']    = $productDetails['NMPRODUTO'];
                                $item['CDARVPROD']    = $productDetails['CDARVPROD'];
                                
                                $this->integrationService->insertItemSale($item);
                                $this->integrationService->insertItemTax($item);
                                
                            }
                            
                            $moviments = [];
                            
                            // Confere se detPag é apenas um pagamento ou um array com vários pagamentos
                            if(!empty($xml["NFe"]["infNFe"]["pag"]["detPag"]['tPag'])) {
                                $moviments[0] = $xml["NFe"]["infNFe"]["pag"]["detPag"];
                            } else {
                                $moviments = $xml["NFe"]["infNFe"]["pag"]["detPag"];
                            }
                            
                            foreach($moviments as $moviment) {
                                $payment = [];
                                
                                $payment["CDFILIAL"] = $sale["CDFILIAL"];
                                $payment["CDCAIXA"] = $sale["CDCAIXA"];
                                $payment["NRSEQVENDA"] = $sale["NRSEQVENDA"];
                                
                                $integrationPayment = $this->integrationService->getIntegrationPayment($moviment['tPag']);
                                $payment["CDTIPORECE"] = $integrationPayment["CDTIPORECE"];
                                
                                $payment["DTABERCAIX"] = \DateTime::createFromFormat('d/m/Y H:i:s', $turcaixa["DTABERTUR"]);
                                
                                $contador                = 'MOVCAIXA'.$sale['CDFILIAL'].$sale['CDCAIXA'].$this->util->dateTimeToString($turcaixa["DTABERTUR"]);
                                $nrsequmovi              = $this->util->newCode($contador, 10);
                                $payment["NRSEQUMOVI"]   = $nrsequmovi;
                                $payment["IDTIPOMOVIVE"] = 'E';
                                $payment["VRMOVIVEND"]   = str_replace(".", ",", $moviment['vPag']);
                                $payment["DTMOVIMCAIXA"] = $dtEntrSale;
                                
                                $this->integrationService->insertMovCaixa($payment);
                            }
                            
                            $fileName = $sale["CDFILIAL"]."-".$sale["CDCAIXA"]."-".$sale["NRSEQVENDA"]."-".$dataXml["id"];
                            
                            $this->util->writeLog('execution', null, date('H:i:s')." - Venda importada $fileName.\n");
                            $this->util->writeLog('order_processed', $fileName.".json", $sale);

                            $this->connection->commit();
                        } catch(Exception\ParamsException $e) {
                            $this->util->writeLog('order_error', $dataXml["id"].".txt", $e->getMessage());
                            
                            $messageBody = file_get_contents(__DIR__ . "/../../templates/defaultTelegramMessage.html");
                            
                            // Limpa xml para ser enviado mensagem (limite de caracteres do Telegram)
                            $dataXml['xml'] = "";
                            $this->util->sendTelegramMessage($messageBody, [
                                ":INTEGRACAO"    => 'Teknisa x ZigPay',
                                ":NUMERO_PEDIDO" => $dataXml["id"],
                                ":NOME_CLIENTE"  => $config["client"],
                                ":NOME_SERVIDOR" => $config["server"],
                                ":ERRO_MSG"      => $e->getMessage(),
                                ":JSON_PEDIDO"   => json_encode($dataXml, JSON_UNESCAPED_UNICODE),
                                ":GERADO_EM"     => date("d/m/Y H:i:s")
                            ]);
                            $this->connection->rollback();
                        } catch(\Exception $e) {
                            $this->util->writeLog('order_error', $dataXml["id"].".txt", $e->getMessage());
                            $this->connection->rollback();
                        }
                    }
                }
            }
            
            $this->util->writeLog('execution', null, date('H:i:s')." - Execução da rotina finalizada.\n");
            return $response->withStatus(200);
        } catch(Exception\NetworkException $e) {
            $now = new \DateTime();
            $this->util->writeLog('network', $now->format('H-i-s').".txt", $e->getMessage());
            echo $e->getMessage();
            return $response->withStatus(500);
        } catch(\Exception $e) {
            $now = new \DateTime();
            $this->util->writeLog('order_error', $now->format('H-i-s').".txt", $e->getMessage());
            echo $e->getMessage();
            return $response->withStatus(500);
        }
    }
    
    private function getBranchesZigpay() {
        
        $configsFile  = file_get_contents(__DIR__ . "/../../configs/configs.json");
        $config       = json_decode($configsFile, true);
        $apiUrl       = $config['apiUrl'];
        $apiToken     = $config['apiToken'];
        $apiRede      = $config['apiRede'];
        
        $curl = curl_init();
        
        curl_setopt_array($curl, [
            CURLOPT_URL             => $apiUrl.'/lojas?rede='.$apiRede,
            CURLOPT_RETURNTRANSFER  => true,
            CURLOPT_ENCODING        => '',
            CURLOPT_MAXREDIRS       => 10,
            CURLOPT_TIMEOUT         => 0,
            CURLOPT_FOLLOWLOCATION  => true,
            CURLOPT_HTTP_VERSION    => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST   => 'GET',
            CURLOPT_HTTPHEADER      => [
                "Authorization: $apiToken"
            ],
            CURLOPT_SSL_VERIFYPEER  => 0
        ]);
        
        $response   = curl_exec($curl);
        $err        = curl_errno($curl);
        $errmsg     = curl_error($curl);
        
        $info = curl_getinfo($curl);
        
        curl_close($curl);
        
        if ($err == true || !empty($errmsg))
            throw new Exception\NetworkException("Ocorreu um erro na chamada da API ZigPay: $errmsg - " . json_encode($info));
            
        return $response;
    }
    
    private function getSalesProductsPerBranch($startDate, $endDate, $branchZigpay) {
        
        $configsFile  = file_get_contents(__DIR__ . "/../../configs/configs.json");
        $config       = json_decode($configsFile, true);
        $apiUrl       = $config['apiUrl'];
        $apiToken     = $config['apiToken'];
        $apiRede      = $config['apiRede'];
        
        $curl = curl_init();
        
        curl_setopt_array($curl, [
            CURLOPT_URL             => $apiUrl."/saida-produtos?dtinicio=$startDate&$endDate&loja=$branchZigpay",
            CURLOPT_RETURNTRANSFER  => true,
            CURLOPT_ENCODING        => '',
            CURLOPT_MAXREDIRS       => 10,
            CURLOPT_TIMEOUT         => 0,
            CURLOPT_FOLLOWLOCATION  => true,
            CURLOPT_HTTP_VERSION    => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST   => 'GET',
            CURLOPT_HTTPHEADER      => [
                "Authorization: $apiToken"
            ],
            CURLOPT_SSL_VERIFYPEER => 0
        ]);
        
        $response = curl_exec($curl);
        
        $err    = curl_errno($curl);
        $errmsg = curl_error($curl);
        $info   = curl_getinfo($curl);
        
        curl_close($curl);
        
        if ($err == true || !empty($errmsg))
            throw new Exception\NetworkException("Ocorreu um erro na chamada da API ZigPay: $errmsg - " . json_encode($info));
        
        return $response;
    }
    
    private function getSalesRevenuePerBranch($startDate, $endDate, $branchZigpay) {
        
        $configsFile  = file_get_contents(__DIR__ . "/../../configs/configs.json");
        $config       = json_decode($configsFile, true);
        $apiUrl       = $config['apiUrl'];
        $apiToken     = $config['apiToken'];
        $apiRede      = $config['apiRede'];
        
        $curl = curl_init();
        
        curl_setopt_array($curl, [
            CURLOPT_URL             => $apiUrl."/faturamento?dtinicio=$startDate&dtfim=$endDate&loja=$branchZigpay&fechado=true",
            CURLOPT_RETURNTRANSFER  => true,
            CURLOPT_ENCODING        => '',
            CURLOPT_MAXREDIRS       => 10,
            CURLOPT_TIMEOUT         => 0,
            CURLOPT_FOLLOWLOCATION  => true,
            CURLOPT_HTTP_VERSION    => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST   => 'GET',
            CURLOPT_HTTPHEADER      => [
                "Authorization: $apiToken"
            ],
            CURLOPT_SSL_VERIFYPEER  => 0
        ]);
        
        $response = curl_exec($curl);
        
        $err    = curl_errno($curl);
        $errmsg = curl_error($curl);
        
        $info = curl_getinfo($curl);
        
        curl_close($curl);
        
        if ($err == true || !empty($errmsg))
            throw new Exception\NetworkException("Ocorreu um erro na chamada da API ZigPay: $errmsg - " . json_encode($info));
        
        return $response;
    }
    
    private function getXmlsPerBranch($page, $startDate, $endDate, $branchZigpay) {
        
        $configsFile  = file_get_contents(__DIR__ . "/../../configs/configs.json");
        $config       = json_decode($configsFile, true);
        $apiUrl       = $config['apiUrl'];
        $apiToken     = $config['apiToken'];
        $apiRede      = $config['apiRede'];
        
        $curl = curl_init();
        
        curl_setopt_array($curl, [
            CURLOPT_URL             => $apiUrl."/invoice?dtinicio=$startDate&dtfim=$endDate&loja=$branchZigpay&page=$page",
            CURLOPT_RETURNTRANSFER  => true,
            CURLOPT_ENCODING        => '',
            CURLOPT_MAXREDIRS       => 10,
            CURLOPT_TIMEOUT         => 0,
            CURLOPT_FOLLOWLOCATION  => true,
            CURLOPT_HTTP_VERSION    => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST   => 'GET',
            CURLOPT_HTTPHEADER      => [
                "Authorization: $apiToken"
            ],
            CURLOPT_SSL_VERIFYPEER  => 0
        ]);
        
        $response = curl_exec($curl);
        
        $err    = curl_errno($curl);
        $errmsg = curl_error($curl);
        
        $info = curl_getinfo($curl);
        
        curl_close($curl);
        
        if ($err == true || !empty($errmsg))
            throw new Exception\NetworkException("Ocorreu um erro na chamada da API ZigPay: $errmsg - " . json_encode($info));
        
        return $response;
    }
    
    private function XML2Array($xmlContent, $out = array()) {
        $xmlObject = is_object($xmlContent) || is_array($xmlContent) ? $xmlContent : simplexml_load_string($xmlContent);
        
        foreach((array) $xmlObject as $index => $node)
            $out[$index] = ( is_object($node) || is_array($node) ) ? $this->XML2Array( $node ) : $node;
        
        return $out;
    }
    
    private function getVersionInfo() {
        $file = file_get_contents(__DIR__ . "/../../version.json");
        return json_decode($file, true);
    }

}