<?php
namespace App\Factory;

use App\Exception;

class IntegrationFactory {
    private $connection;

    public function __construct (\Doctrine\DBAL\Connection $connection) {
        $this->connection = $connection;
    }

    public function insertSale($sale) {
        $sql = "
            INSERT INTO VENDA
        	(CDFILIAL, CDLOJA, CDCAIXA, NRSEQVENDA, DTABERTUR, DTVENDA, 
        	 DTENTRVENDA, DTEMISSAONFCE, 
        	 VRDESCVENDA, IDSTATUSNFCE, IDSITUVENDA, IDORIGEMVENDA,
        	 IDTPEMISVEND,  CDOPERADOR, CDCLIENTE,  CDEMPRESA,  CDFILIALTUR,  CDCAIXATUR, 
        	 IDTPAMBNFCE, IDTIPOVENDA, VRTXSEVENDA, CDCONSUMIDOR, VRTOTVENDA, NRINSCRCONS, NRSERIEIMPVND, DSOBSFINVEN, DSARQXMLNFCE, NRACESSONFCE)
        	VALUES
        	(:CDFILIAL, :CDLOJA, :CDCAIXA, :NRSEQVENDA, 
        	 TO_DATE(:DTABERTUR,'DD/MM/YYYY HH24:MI:SS'), 
        	 TO_DATE(:DTVENDA,'DD/MM/YYYY HH24:MI:SS'),
        	 TRUNC(TO_DATE(:DTENTRVENDA,'DD/MM/YYYY HH24:MI:SS')), 
        	 TRUNC(TO_DATE(:DTEMISSAONFCE,'DD/MM/YYYY HH24:MI:SS')),
        	 :VRDESCVENDA, 'A', :IDSITUVENDA, :IDORIGEMVENDA,
        	 'N', :CDOPERADOR, :CDCLIENTE, :CDEMPRESA, :CDFILIALTUR, :CDCAIXATUR, '1', 'I', :VRTXSEVENDA, 
        	 :CDCONSUMIDOR, :VRTOTVENDA,  :NRINSCRCONS, :NRSERIEIMPVND, :DSOBSFINVEN, NULL, :NRACESSONFCE)
        ";
        
    	$params = array(
            ":CDFILIAL"         => $sale["CDFILIAL"],
            ":CDLOJA"           => $sale["CDLOJA"],
            ":CDCAIXA"          => $sale["CDCAIXA"],
            ":NRSEQVENDA"       => $sale["NRSEQVENDA"],
            ":DTABERTUR"        => $sale["DTABERTUR"]->format('d/m/Y H:i:s'),
            ":DTVENDA"          => $sale["DTVENDA"]->format('d/m/Y H:i:s'),
            ":DTENTRVENDA"      => $sale["DTENTRVENDA"]->format('d/m/Y H:i:s'),
            ":DTEMISSAONFCE"    => $sale["DTEMISSAONFCE"]->format('d/m/Y H:i:s'),
            ":VRDESCVENDA"      => $sale["VRDESCVENDA"], 
            ":IDSITUVENDA"      => $sale["IDSITUVENDA"], 
            ":CDOPERADOR"       => $sale["CDOPERADOR"],  
            ":CDCLIENTE"        => $sale["CDCLIENTE"],   
            ":CDEMPRESA"        => $sale["CDEMPRESA"],  
            ":CDFILIALTUR"      => $sale["CDFILIALTUR"],
            ":CDCAIXATUR"       => $sale["CDCAIXATUR"],
            ":IDORIGEMVENDA"    => $sale["IDORIGEMVENDA"],
            ":VRTXSEVENDA"      => $sale["VRTXSEVENDA"],
            ":CDCONSUMIDOR"     => $sale["CDCONSUMIDOR"],
            ":VRTOTVENDA"       => str_replace(".", ",", $sale["VRTOTVENDA"]),
            ":NRINSCRCONS"      => $sale['NRINSCRCONS'],
            ":NRSERIEIMPVND"    => $sale['NRSERIEIMPVND'],
            ":DSOBSFINVEN"      => $sale['DSOBSFINVEN'],
            ":NRACESSONFCE"     => $sale["NRACESSONFCE"]
    	);
    	
    	$this->connection->executeQuery($sql, $params);
    }
    
    public function insertSaleXml($saleXml) {
        $sql = "
            INSERT INTO ARQXMLNFCESAT
        	(CDFILIAL, CDCAIXA, NRSEQVENDA, DSARQXMLNFCE, DSARQXMLCANCNFCE)
        	VALUES
        	(:CDFILIAL, :CDCAIXA, :NRSEQVENDA, :DSARQXMLNFCE, :DSARQXMLCANCNFCE)";
        
    	$params = array(
            ":CDFILIAL"         => $saleXml["CDFILIAL"],
            ":CDCAIXA"          => $saleXml["CDCAIXA"],
            ":NRSEQVENDA"       => $saleXml["NRSEQVENDA"],
            ":DSARQXMLNFCE"     => $saleXml["DSARQXMLNFCE"],
            ":DSARQXMLCANCNFCE" => $saleXml["DSARQXMLCANCNFCE"]
    	);
    	
    	$this->connection->executeQuery($sql, $params);
    }
    
    public function insertItemSale($item) {
        $sql = "INSERT INTO ITEMVENDA
            	    (CDFILIAL, CDLOJA, CDCAIXA, NRSEQVENDA, NRSEQUITVEND, QTPRODVEND, 
            	    VRUNITVEND, CDPRODUTO, VRDESITVEND, VRACRITVEND, VRUNITVENDCL, NRLANCESTQ, CDFILIALEST)
            	VALUES
            	    (:CDFILIAL, :CDLOJA, :CDCAIXA, :NRSEQVENDA, :NRSEQUITVEND, :QTPRODVEND, 
            	    :VRUNITVEND, :CDPRODUTO, :VRDESITVEND, :VRACRITVEND, :VRUNITVENDCL, NULL, NULL)";
            
        $params = array(
        	":CDFILIAL"     => $item["CDFILIAL"],
        	":CDLOJA"       => $item["CDLOJA"],
        	":CDCAIXA"      => $item["CDCAIXA"],
        	":NRSEQVENDA"   => $item["NRSEQVENDA"],
        	":NRSEQUITVEND" => $item["NRSEQUITVEND"],
        	":QTPRODVEND"   => $item["QTPRODVEND"],
        	":VRUNITVEND"   => $item["VRUNITVEND"],
        	":CDPRODUTO"    => $item["CDPRODUTO"],
        	":VRDESITVEND"  => $item["VRDESITVEND"],
        	":VRACRITVEND"  => $item["VRACRITVEND"],
        	":VRUNITVENDCL" => $item["VRUNITVENDCL"]
    	);

    	$this->connection->executeQuery($sql, $params);
    }
    
    public function insertMovCaixa($mov) {
        $sql = "INSERT INTO MOVCAIXA
            	(CDFILIAL, CDCAIXA, NRSEQVENDA, DTABERCAIX, NRSEQUMOVI, IDTIPOMOVIVE, VRMOVIVEND, CDTIPORECE, DTHRINCMOV,
            	DTMOVIMCAIXA, DSMOVIVEND)
            	VALUES
            	(:CDFILIAL, :CDCAIXA, :NRSEQVENDA, TO_DATE(:DTABERCAIX,'DD/MM/YYYY HH24:MI:SS'), :NRSEQUMOVI, :IDTIPOMOVIVE,
            	:VRMOVIVEND, :CDTIPORECE, SYSDATE, TO_DATE(:DTMOVIMCAIXA,'DD/MM/YYYY HH24:MI:SS'), :DSMOVIVEND)
        ";
            	
        $params = array(
            ':CDFILIAL' 	=> $mov["CDFILIAL"],
            ':CDCAIXA'  	=> $mov["CDCAIXA"],
            ':DTMOVIMCAIXA' => $mov["DTMOVIMCAIXA"]->format('d/m/Y H:i:s'),
            ':NRSEQUMOVI'   => $mov["NRSEQUMOVI"],
            ':IDTIPOMOVIVE' => $mov["IDTIPOMOVIVE"],
            ':VRMOVIVEND'   => str_replace(".", ",", $mov["VRMOVIVEND"]),
            ':NRSEQVENDA'   => $mov["NRSEQVENDA"],
            ':CDTIPORECE'   => $mov["CDTIPORECE"],
            ':DTABERCAIX'   => $mov["DTABERCAIX"]->format('d/m/Y H:i:s'),
            ':DSMOVIVEND'   => "Movimentação incluída através do sistema de integração Zigpay"
        );
    	
    	$this->connection->executeQuery($sql, $params);	
    }
    
    public function insertTurCaixa($tur) {
        $sql = "INSERT INTO TURCAIXA
                    (CDFILIAL, CDCAIXA, DTABERCAIX, CDOPERADOR) 
                VALUES
            	(:CDFILIAL, :CDCAIXA, SYSDATE, :CDOPERADOR)";
            	
        $params = array(
            ':CDFILIAL' 	=> $tur["CDFILIAL"],
            ':CDCAIXA'  	=> $tur["CDCAIXA"],
            ':CDOPERADOR'   => $tur["CDOPERADOR"]
        );
    	
    	$this->connection->executeQuery($sql, $params);	
    }
    
    public function closePos($cdfilial, $cdcaixa, $dtfechcaix, $cdoperador, $idatuturcaixa) {
        $sql = "UPDATE TURCAIXA
          SET DTFECHCAIX = TO_DATE(:DTFECHCAIX,'DD/MM/YYYY HH24:MI:SS'),
              CDOPERFECH = :CDOPERFECH,
              CDOPERULTATU = :CDOPERFECH,
              IDATUTURCAIXA = :IDATUTURCAIXA
        WHERE CDFILIAL = :CDFILIAL
          AND DTFECHCAIX IS NULL
          AND CDCAIXA = :CDCAIXA";
            	
        $params = array(
            ':CDFILIAL' 	 => $cdfilial,
            ':CDCAIXA'  	 => $cdcaixa,
            ':DTFECHCAIX'    => $dtfechcaix->format('d/m/Y H:i:s'),
            ':CDOPERFECH'    => $cdoperador,
            ':IDATUTURCAIXA' => $idatuturcaixa
        );
    	
    	$this->connection->executeQuery($sql, $params);	
    }
    
    public function getBranchParams($branchId) {
        $sql = "
            SELECT IF.CDFILIAL, IF.IDUTLENTRETERC, IF.IDRETTXENTR, 
                   I.IDUTLVNDPDRPALC, IF.CDLOJA, IF.CDCAIXA, F.CDEMPRESA
              FROM INTEGRACAOFILI IF
              JOIN INTEGRACAO I
                ON IF.CDINTEGRACAO = I.CDINTEGRACAO
              JOIN FILIAL F 
                ON IF.CDFILIAL = F.CDFILIAL
             WHERE IF.IDTOKEN = :IDTOKEN
               AND I.IDINTEGRACAO = 'ZIG'
        ";
        
        $params = [
            ':IDTOKEN' => $branchId
        ];
        
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function getStandartParameters ($branch) {
        $sql = "
            SELECT CDVENDEDOR, CDCLIENTE
              FROM PARAVEND
            WHERE CDFILIAL = :CDFILIAL";
            
        $params = array(
            ":CDFILIAL" => $branch    
        );
        
        $standart = $this->connection->fetchAssoc($sql, $params);
        
        if (!isset($standart["CDCLIENTE"]) || empty($standart["CDCLIENTE"]))  
            throw new Exception\ParamsException("Não foi encontrado cliente padrão para a filial ".$branch);
        
        if (!isset($standart["CDVENDEDOR"]) || empty($standart["CDVENDEDOR"]))  
            throw new Exception\ParamsException("Não foi encontrado vendedor padrão para a filial ".$branch);
        
        return $standart;
    }
    
    public function getStandartCashier ($branch, $vendor) {
        $sql = "
            SELECT V.CDOPERADOR, V.CDCAIXA, C.CDLOJA
              FROM VENDEDOR V
                LEFT JOIN CAIXA C
                 ON V.CDFILIAL = C.CDFILIAL
                  AND V.CDCAIXA = C.CDCAIXA
            WHERE V.CDFILIAL   = :CDFILIAL
              AND V.CDVENDEDOR = :CDVENDEDOR";
              
        $params = array(
            ":CDFILIAL"   => $branch,
            ":CDVENDEDOR" => $vendor
        );
        
        $cashier = $this->connection->fetchAssoc($sql, $params);
        
        if (empty($cashier)) 
            throw new Exception\ParamsException("Não foi encontrado caixa padrão ou operador padrão para a filial ". $branch);
        
        return $cashier;
    }
    
    public function getProductTaxes ($branch, $product) {
        $sql = "
            SELECT
              AL.VRPEALIMPFIS, AL.CDIMPOSTO, IP.IDTPIMPOSFIS, IP.CDINTIMPOSTO, IP.IDTRATIMPO,
              AL.CDCSTICMS, AL.CDCSTPISCOF, AL.CDCFOPPFIS, AL.VRALIQPIS, AL.VRALIQCOFINS,
              AL.IDMODALBASECALC, AL.VRPERCREDUCAO, AL.VRALIQIBPT, AL.IDINCIDEPISCOF
            FROM
              ALIQIMPFIS AL, IMPOSTO IP
            WHERE (AL.CDFILIAL  = :CDFILIAL)
              AND (AL.CDPRODUTO = :CDPRODUTO)
              AND (AL.CDIMPOSTO = IP.CDIMPOSTO)";
              
        $params = array(
            ":CDFILIAL"  => $branch,
            ":CDPRODUTO" => $product['CDPRODUTO']
        );
        
        $taxes = $this->connection->fetchAssoc($sql, $params);
        
        if (empty($taxes)) 
            throw new Exception\ParamsException("Não foi encontrado imposto parametrizado para o produto {$product['NMPRODUTO']} - cód de arvore Teknisa: {$product['CDARVPROD']}.");
        
        return $taxes;
    }
    
    public function insertItemTax($tax) {
        $sql = "INSERT INTO ITVENDAIMPOS
          (CDFILIAL, CDCAIXA, NRSEQVENDA, NRSEQUITVEND,
          NRSEQITIMPOS, CDIMPOSTO, VRPEALPRODIT, VRIMPOPRODIT,
          CDIMPOSTOEX, CDCSTPRODI, CDCSTPRODPC, CDCFOPPROD,
          VRPERCOFINS, VRPERPIS, IDMODALBASECALC, VRBASECALCREDUZ,
          VRIMPOPRODREDUZ, VRBASECALCICMS, VRBCREDUZICMS, VRPRBCREDUICMS,
          VRIMPPIS, VRIMPCOFINS, VRTOTTRIBIBPT, VRBCPISCOFINS)
        VALUES (:CDFILIAL, :CDCAIXA, :NRSEQVENDA, :NRSEQUITVEND,
          :NRSEQITIMPOS, :CDIMPOSTO, :VRPEALPRODIT, :VRIMPOPRODIT,
          :CDIMPOSTOEX, :CDCSTPRODI, :CDCSTPRODPC, :CDCFOPPROD,
          :VRPERCOFINS, :VRPERPIS, :IDMODALBASECALC, :VRBASECALCREDUZ,
          :VRIMPOPRODREDUZ, :VRBASECALCICMS, :VRBCREDUZICMS, :VRPRBCREDUICMS,
          :VRIMPPIS, :VRIMPCOFINS, :VRTOTTRIBIBPT, :VRBCPISCOFINS)";
            	
        $params = array(
        	":CDFILIAL"        => $tax['CDFILIAL'],
        	":CDCAIXA"         => $tax['CDCAIXA'],
        	":NRSEQVENDA"      => $tax['NRSEQVENDA'],
        	":NRSEQUITVEND"    => $tax['NRSEQUITVEND'],
        	":NRSEQITIMPOS"    => $tax['NRSEQITIMPOS'],
        	":CDIMPOSTO"       => $tax['CDIMPOSTO'],
        	":VRPEALPRODIT"    => $tax['VRPEALPRODIT'],
        	":VRIMPOPRODIT"    => $tax['VRIMPOPRODIT'],
        	":CDIMPOSTOEX"     => $tax['CDIMPOSTOEX'],
        	":CDCSTPRODI"      => $tax['CDCSTPRODI'],
        	":CDCSTPRODPC"     => $tax['CDCSTPRODPC'],
        	":CDCFOPPROD"      => $tax['CDCFOPPROD'],
        	":VRPERCOFINS"     => $tax['VRPERCOFINS'],
        	":VRPERPIS"        => $tax['VRPERPIS'],
        	":IDMODALBASECALC" => $tax['IDMODALBASECALC'],
        	":VRBASECALCREDUZ" => $tax['VRBASECALCREDUZ'],
        	":VRIMPOPRODREDUZ" => $tax['VRIMPOPRODREDUZ'],
        	":VRBASECALCICMS"  => $tax['VRBASECALCICMS'],
        	":VRBCREDUZICMS"   => $tax['VRBCREDUZICMS'],
        	":VRPRBCREDUICMS"  => $tax['VRPRBCREDUICMS'],
        	":VRIMPPIS"        => $tax['VRIMPPIS'],
        	":VRIMPCOFINS"     => $tax['VRIMPCOFINS'],
        	":VRTOTTRIBIBPT"   => $tax['VRTOTTRIBIBPT'],
        	":VRBCPISCOFINS"   => $tax['VRBCPISCOFINS']
    	);

    	$this->connection->executeQuery($sql, $params);
    }
    
    public function getProduct ($product) {
        $productReturn = [];
        $cdProduto = $product['cProd'];
        
        $sql = "
            SELECT CDPRODUTO, CDARVPROD, NMPRODUTO, IDTIPOCOMPPROD
              FROM PRODUTO PR
             WHERE CDPRODINTE = :CDPRODINTE
        ";

        $productCode = str_replace(".", "", $cdProduto);
        $productCode = preg_replace("/[^0-9A-Z]/", "", $productCode);

        $params = array(
            ':CDPRODINTE' => $productCode,
        );
        
        $extProduct = $this->connection->fetchAssoc($sql, $params);
        
        $productReturn = $extProduct;
        
        if(empty($extProduct)) {
            
            $sql = "
                SELECT P.CDPRODUTO, P.CDARVPROD, P.NMPRODUTO, P.IDTIPOCOMPPROD
                  FROM PRODEXTERNOINTE PI 
                    JOIN PRODUTO P ON PI.CDPRODUTO = P.CDPRODUTO 
                WHERE PI.CDPROJETO = '018' 
                AND PI.CDPRODINTE = :CDPRODINTE
            ";
            
            $productCode = str_replace(".", "", $cdProduto);
            $productCode = preg_replace("/[^0-9A-Z]/", "", $productCode);
            
            $params = array(
                ':CDPRODINTE' => $productCode,
            );
            
            $newExtProduct = $this->connection->fetchAssoc($sql, $params);
            
            $productReturn = $newExtProduct;
            
            if(empty($newExtProduct)) {
                $sql = "
                    SELECT CDPRODUTO, CDARVPROD, NMPRODUTO, IDTIPOCOMPPROD
                      FROM PRODUTO PR
                     WHERE CDARVPROD = :CDARVPROD OR CDPRODUTO = :CDPRODUTO
                ";
    
                $productCode = str_replace(".", "", $cdProduto);
                $productCode = preg_replace("/[^0-9A-Z]/", "", $productCode);
        
                $params = array(
                    ':CDARVPROD' => $productCode,
                    ':CDPRODUTO' => $productCode
                );
            
                $productTek = $this->connection->fetchAssoc($sql, $params);
                
                if(empty($productTek))
                    throw new Exception\ParamsException("O produto {$product['xProd']} - cód ZigPay: {$product['cProd']} não foi encontrado na base, necessário a revisão da parametrização do mesmo.");
                
                $productReturn = $productTek;
            }
        }
        
        return $productReturn;
    }
    
    public function getOpeningPos ($cdfilial, $cdcaixa) {
        $sql = "SELECT CDCAIXA, TO_CHAR(DTABERCAIX, 'DD/MM/YYYY HH24:MI:SS') AS DTABERTUR, IDATUTURCAIXA
                    FROM TURCAIXA TC
                    WHERE CDFILIAL = :CDFILIAL
                    AND CDCAIXA = :CDCAIXA
                    AND DTFECHCAIX IS NULL
        ";
        
        $params = array(
            ":CDFILIAL"  => $cdfilial,
            ":CDCAIXA" => $cdcaixa
        );
        
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    public function insertSangria ($sangria) {
        $sql = "INSERT INTO MOVCAIXA
                    (CDFILIAL, CDCAIXA, DTABERCAIX, NRSEQUMOVI,
                        DTHRINCMOV, IDTIPOMOVIVE, VRMOVIVEND,
                            CDTIPORECE, DTMOVIMCAIXA)
                VALUES
                    (:CDFILIAL, :CDCAIXA, 
                    TO_DATE(:DTABERCAIX, 'DD/MM/YYYY HH24:MI:SS'), :NRSEQUMOVI,
                    
                    TO_DATE(:DTHRINCMOV, 'DD/MM/YYYY HH24:MI:SS'), :IDTIPOMOVIVE, :VRMOVIVEND,
                    :CDTIPORECE, TO_DATE(:DTMOVIMCAIXA, 'DD/MM/YYYY HH24:MI:SS')
                    )
        ";

        $params = [
            ":CDFILIAL"     => $sangria["CDFILIAL"],
            ":CDCAIXA"      => $sangria["CDCAIXA"],
            ":DTABERCAIX"   => $sangria["DTABERCAIX"]->format('d/m/Y H:i:s'),
            ":NRSEQUMOVI"   => $sangria["NRSEQUMOVI"],
            ":DTHRINCMOV"   => $sangria["DTHRINCMOV"]->format('d/m/Y H:i:s'),
            ":IDTIPOMOVIVE" => $sangria["IDTIPOMOVIVE"],
            ":VRMOVIVEND"   => $sangria["VRMOVIVEND"],
            ":CDTIPORECE"   => $sangria["CDTIPORECE"],
            ":DTMOVIMCAIXA" => $sangria["DTMOVIMCAIXA"]->format('d/m/Y H:i:s')
        ];
        
        $this->connection->executeQuery($sql, $params);
    }
    
    public function getIntegrationPayment($cdPagExt, $revenue = false) {
        $sql = "SELECT CDTIPORECE
                  FROM TIPORECEINTE TP
                  JOIN INTEGRACAO INTE 
                    ON TP.CDINTEGRACAO   = INTE.CDINTEGRACAO
                 WHERE 
                    INTE.IDINTEGRACAO = :IDINTEGRACAO
                   AND CDTPRECEINTE = :CDTPRECEINTE";
                   
        $params = array(
            ":IDINTEGRACAO"  => 'ZIG',
            ":CDTPRECEINTE"  => $cdPagExt
        );
        
        $payment = $this->connection->fetchAssoc($sql, $params);
        
        if(empty($payment) && $revenue == false) 
            throw new Exception\ParamsException("O recebimento externo $cdPagExt não esta mapeado. Favor consultar a tela Cadastro de integração, aba Tipo de recebimento.");
        
        return $payment;
    }
    
    public function getMovementIncrement($mov) {
        $sql = "
            SELECT NRSEQUMOVI 
              FROM MOVCAIXA 
             WHERE CDFILIAL = :CDFILIAL
               AND CDCAIXA  = :CDCAIXA
               AND DTABERCAIX = TO_DATE(:DTABERCAIX, 'DD/MM/YYYY HH24:MI:SS')
          ORDER BY NRSEQUMOVI DESC
             FETCH NEXT 1 ROWS ONLY
        ";
                   
        $params = array(
            ":CDFILIAL"     => $mov["CDFILIAL"],
            ":CDCAIXA"      => $mov["CDCAIXA"],
            ":DTABERCAIX"   => $mov["DTABERCAIX"]->format('d/m/Y H:i:s')
        );
        
        return $this->connection->fetchAssoc($sql, $params);
    }
    
    //****** Revisar custo dessa consulta ******
    public function getSalesByIds($cdfilial, $ids) {
        $sql = "
            SELECT CDFILIAL, CDCAIXA, NRSEQVENDA, VRTOTVENDA, NRINSCRCONS, DSOBSFINVEN
              FROM VENDA 
             WHERE DSOBSFINVEN IN (:DSOBSFINVEN)
               AND CDFILIAL = :CDFILIAL
        ";
        
        $params = array(
            ":DSOBSFINVEN" => $ids,
            ":CDFILIAL" => $cdfilial
        );
        
        $types = array(
            ':DSOBSFINVEN' => \Doctrine\DBAL\Connection::PARAM_STR_ARRAY
        );
        
        return $this->connection->fetchAll($sql, $params, $types);
    }
    
    
    public function updateSaleId($cdfilial, $cdcaixa, $nrseqvenda, $id) {
        $sql = "
        UPDATE VENDA 
           
           SET DSOBSFINVEN = :DSOBSFINVEN
           
         WHERE CDFILIAL   = :CDFILIAL 
           AND CDCAIXA    = :CDCAIXA
           AND NRSEQVENDA = :NRSEQVENDA
        ";
            	
        $params = array(
        	":CDFILIAL"    => $cdfilial,
        	":CDCAIXA"     => $cdcaixa,
        	":NRSEQVENDA"  => $nrseqvenda,
        	":DSOBSFINVEN" => $id
    	);
    	    
    	$this->connection->executeQuery($sql, $params);
    	    
    }
}
