<?php

namespace App\Util;

use App\Exception;
use App\Util\Telegram;

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception as MailerException;

class Util {
    
    const TELEGRAM_BOT_TOKEN = "5749191530:AAGBPYNx38f8ez8yrXtNnG1PgXqzt-uNznE";
    
    private $connection;
    
    public function __construct (\Doctrine\DBAL\Connection $connection) {
        $this->connection = $connection;
    }
    
    public function newCode ($counterName, $size) {
        try {
            $nrseq = null;
            $connection = $this->connection;
            $storedProcedure = new StoredProcedure($connection, "NOVO_CODIGO_NT");
            $storedProcedure->addParam(new Param("P_CONTADOR", Param::PARAM_INPUT, $counterName, Param::PARAM_TYPE_STR, strlen($counterName)));
            $storedProcedure->addParam(new Param("P_SEQUENCIAL", Param::PARAM_OUTPUT, $nrseq, Param::PARAM_TYPE_INT, 20));
            $result = $storedProcedure->execute();
            return substr($result["P_SEQUENCIAL"], strlen($result["P_SEQUENCIAL"])-$size);
        } catch (\Exception $e) {
            throw new \Exception($e->getMessage());
        }
    }

    /**
     *
     *
     * @param StoredProcedure $procedure The procedure to be executed.
     * @param array $paramValues Param values to override values present in Param instance.
     *
     * @return array The output parameters indexed by name.
     */
    public function executeProcedure(StoredProcedure $procedure, array $paramValues = array()) {
        $queryStmt = $this->getQueryString($procedure);
        $stmt = $this->connection->prepare($queryStmt);
        $valuesOutput = array();
        foreach ($procedure->getParams() as $param) {
            if ($param->isOutput()) {
                $valuesOutput[$param->getName()] = $param->getValue();
                $stmt->bindParam($param->getParamAlias(), $valuesOutput[$param->getName()], $param->getType(), $param->getLength());
            } else {
                $stmt->bindValue($param->getParamAlias(), $param->getValue(), $param->getType());
            }
        }

        $stmt->execute();
        return $valuesOutput;
    }

    /**
     * @param StoredProcedure $procedure
     * @return string
     */
    protected function getQueryString(StoredProcedure $procedure) {
        $paramNames = array_map(function (Param $param) {
            return ":" . $param->getName();
        }, $procedure->getParams());
        $paramString = implode(", ", $paramNames);
        return "CALL " . $procedure->getName() . " ( " . $paramString . " )";
    }
    
    public function getMailList() {
        $list = [];

        $sql = "
            SELECT DSEMAILTEC 
              FROM LISTAEMAILTEC
             WHERE CDPROJETO = '018'
        ";
        
        $result = $this->connection->fetchAll($sql);
        
        if(empty($result)) {
            throw new Exception\GeneralErrorException("Cadastro de responsáveis técnicos inexistente.");
        }
        
        foreach($result as $row) {
            if(!empty($row['DSEMAILTEC']) && filter_var($row['DSEMAILTEC'], FILTER_VALIDATE_EMAIL)) {
                array_push($list, $row['DSEMAILTEC']);
            }
        }
        
        if(empty($list)) {
            throw new Exception\GeneralErrorException("Cadastro de responsáveis técnicos inexistente.");
        }
        
        return $list;
    }
    
    public function sendTelegramMessage($body, $params){
        $telegram = new Telegram();
        
        $configsFile  = file_get_contents(__DIR__ . "/../../configs/configs.json");
        $config       = json_decode($configsFile, true);

        $telegram->setCredentials('bot'.self::TELEGRAM_BOT_TOKEN, $config["telegramChannel"]);
        return $telegram->msg(str_replace(array_keys($params), array_values($params), $body));
    }
    
    public function getCurrentTimezone($state) {
        $timezones = [
            "AC" => "America/Rio_branco",   "AL" => "America/Maceio",
            "AP" => "America/Belem",        "AM" => "America/Manaus",
            "BA" => "America/Bahia",        "CE" => "America/Fortaleza",
            "DF" => "America/Sao_Paulo",    "ES" => "America/Sao_Paulo",
            "GO" => "America/Sao_Paulo",    "MA" => "America/Fortaleza",
            "MT" => "America/Cuiaba",       "MS" => "America/Campo_Grande",
            "MG" => "America/Sao_Paulo",    "PR" => "America/Sao_Paulo",
            "PB" => "America/Fortaleza",    "PA" => "America/Belem",
            "PE" => "America/Recife",       "PI" => "America/Fortaleza",
            "RJ" => "America/Sao_Paulo",    "RN" => "America/Fortaleza",
            "RS" => "America/Sao_Paulo",    "RO" => "America/Porto_Velho",
            "RR" => "America/Boa_Vista",    "SC" => "America/Sao_Paulo",
            "SE" => "America/Maceio",       "SP" => "America/Sao_Paulo",
            "TO" => "America/Araguaia",    
        ];
       
        return $timezones[$state];
    }

    public function writeLog($type, $fileName, $content) {

        $configsFile  = file_get_contents(__DIR__ . "/../../configs/configs.json");
        $config       = json_decode($configsFile, true);

        $clientFolder = $this->connection->getParams();

        $clientFolder = (isset($clientFolder['dbname'])) ? $clientFolder['dbname'] : "undefined";

        $basePath     = $config['logPath'] . "/$clientFolder";

        if($type == 'order') {
            $folder      = $basePath . "/orders/" . date("Y") . "/" . date("m") . "/" . date("d") . "/";
            $currentFile = "$folder/$fileName";
            if(!file_exists($folder)) {
                mkdir($folder, 0775, true);
            }

            file_put_contents($currentFile, json_encode($content, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
        }

        if($type == 'order_processed') {
            $folder      = $basePath . "/processed/" . date("Y") . "/" . date("m") . "/" . date("d") . "/";
            $currentFile = "$folder/$fileName";
            if(!file_exists($folder)) {
                mkdir($folder, 0775, true);
            }

            file_put_contents($currentFile, json_encode($content, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
        }

        if($type == 'order_error') {
            $folder      = $basePath . "/error/" . date("Y") . "/" . date("m") . "/" . date("d") . "/";

            $currentFile = "$folder/$fileName";

            if(!file_exists($folder)) {
                mkdir($folder, 0775, true);
            }
            file_put_contents($currentFile, json_encode($content, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
        }
        
        if($type == 'network') {
            $folder      = $basePath . "/networkError/" . date("Y") . "/" . date("m") . "/" . date("d") . "/";
            $currentFile = "$folder/$fileName";
            if(!file_exists($folder)) {
                mkdir($folder, 0775, true);
            }

            file_put_contents($currentFile, $content);
        }

        if($type == 'execution') {
            $folder      = $basePath . "/execution/" . date("Y") . "/" . date("m") . "/";

            $currentFile = "$folder" . date("d") . ".txt";

            if(!file_exists($folder)) {
                mkdir($folder, 0775, true);
            }

            file_put_contents($currentFile, $content, FILE_APPEND);
        }
        
        if($type == 'revenue_error') {
            $folder      = $basePath . "/revenue_error/" . date("Y") . "/" . date("m") . "/" . date("d") . "/";

            $currentFile = "$folder/$fileName";

            if(!file_exists($folder)) {
                mkdir($folder, 0775, true);
            }
            file_put_contents($currentFile, json_encode($content, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
        }
        
        if($type == 'revenue') {
            $folder      = $basePath . "/revenue/" . date("Y") . "/" . date("m") . "/";

            $currentFile = "$folder" . date("d") . ".txt";

            if(!file_exists($folder)) {
                mkdir($folder, 0775, true);
            }

            file_put_contents($currentFile, $content, FILE_APPEND);
        }
    }
    
    private function decrypt($string) {
        $output = false;
        $encrypt_method = "AES-256-CBC";
    
        $secret_key = 'ZEEDHI';
        $secret_iv  = 'ZEEDHI IV';
    
        $key = hash('sha256', $secret_key);
        $iv  = substr(hash('sha256', $secret_iv), 0, 16);

        $output = openssl_decrypt(base64_decode($string), $encrypt_method, $key, 0, $iv);
        return $output;
    }
    
    public function trataMascaraImposto($valor) {
		$valor = str_replace(' ', '', $valor);
		$valor = str_replace(',', '.', $valor);
		return floatval($valor);
	}
	
	public function roundABNT($valor, $casasdecimais) {
        $pot10 = pow(10, $casasdecimais);

        $trunc = floor($valor * $pot10) / $pot10;
        $valorDescartado = abs($valor) - abs($trunc);

        $limiteDescarte = 0.5 / $pot10;
        $incrementoUltimaCasa = 1 / $pot10;
        if (self::floatEquals($valorDescartado, $limiteDescarte)) {
            return self::isEven($trunc * $pot10) ? $trunc : $trunc + $incrementoUltimaCasa;
        } else if (abs($valorDescartado) < $limiteDescarte) {
            return $trunc;
        } else if (abs($valorDescartado) > $limiteDescarte) {
            return $trunc + $incrementoUltimaCasa;
        }

        // return $result;
    }
    
    public function isEven($a) {
        $intA = round($a, 0);

        if (self::floatEquals($intA, $a)) {
            return $intA % 2 == 0;
        } else {
			throw new \Exception("Argument passed to function 'isEven' is not an integer");
        }
    }
    
    public function floatEquals($a, $b) {
        $precision = 5;
        return round($a, $precision) == round($b, $precision);
    }
    
    public function percentageToAbsolute($baseValue, $percentualValue) {
        return $baseValue * $percentualValue * 0.01;
	}
	
	public function trunc($val, $f = "2") {
	    if (($p = strpos($val, '.')) !== false) {
	        $val = floatval(substr($val, 0, $p + 1 + $f));
	    }
	    return $val;
	}
	
    public function cleanNumbers($numbers){
        foreach($numbers as $key => $n){
            if(is_float($n)) $numbers[$key] = str_replace(".", ",", $n);
        }
        return $numbers;
    }
    
    public function dateTimeToString($date){
        if (is_a($date, 'DateTime')) {
            return $date->format('d/m/Y H:i:s');
        } else {
            return $date;
        }
    }
}